@@ -13,5 +13,6 @@ var structTplParams =
     [ "src_ref_frame", "structTplParams.html#a0df19e4c6859e886d653eafb1deb6fc5", null ],
     [ "ref_frame", "structTplParams.html#afbb8768ff7a4e0d87dc72fa0122a6ec4", null ],
     [ "tpl_mt_sync", "structTplParams.html#a5c1a2778d685c998fa7045b00070c0b9", null ],
-    [ "border_in_pixels", "structTplParams.html#a710006b5c6067d97bd8768f65982146b", null ]
+    [ "border_in_pixels", "structTplParams.html#a710006b5c6067d97bd8768f65982146b", null ],
+    [ "r0_adjust_factor", "structTplParams.html#ae7956489e4719a66b6738dfbd3fa1311", null ]
 ];
\ No newline at end of file
